<%
/*******************************************************************************
* Copyright (C) 2006 Ping Identity Corporation All rights reserved.
*
* This software is licensed under the Open Software License v2.1 (OSL v2.1).
*
* A copy of this license has been provided with the distribution of this
* software. Additionally, a copy of this license is available at:
* http://opensource.org/licenses/osl-2.1.php
*
******************************************************************************
*/
%>
<%@ page language="java" contentType="text/html; charset=ISO-8859-1"
    pageEncoding="ISO-8859-1"%>
<%@ page import = "com.pingidentity.adapters.pftoken.core.PFTokenException" %>
<%@ page import = "com.pingidentity.adapters.pftoken.core.PFTokenAgent" %>
<%@ page import = "com.pingidentity.adapters.pftoken.util.PFTokenConstants" %>

<%!

	/**
	 * parsePFToken method uses the Java Integration Kit API to create an
	 * instance of Sp Agent and returns the user attributes obtained from
	 * PFTOKEN

	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
  	 * @return Map
	 * 				map of user attributes
	 */
	private Map parsePFToken(HttpServletRequest request,
			HttpServletResponse response) throws IOException, ServletException {

		Properties configProperties= getProperties(configFilePath);

		// Get password for encryption
		String password = configProperties.getProperty("password");

		// Get PFTOKEN Holder name
		String holderName = configProperties.getProperty("holderName");

		// Create PFTOKEN Sp Agent
		PFTokenAgent spAgent = new PFTokenAgent(password,holderName);

		Map userInfo = null;
		try {
			// Get attributes from the PFTOKEN 
			spAgent.extractFromRequest(request, response);
			userInfo = spAgent.getAttributes();
		}
		catch(PFTokenException e) {
			throw new ServletException(e);
		}
		if(userInfo != null) {

			// Get sessionID created by the Standard SP Adapter and save it in
			// ArrayList for SLO purposes
			String userSessionID = spAgent.getSessionID();

			HttpSession session = request.getSession(true);
			ArrayList userSessionList = (ArrayList)session.getAttribute(USER_SESSION_ID);
			if(userSessionList == null) {
				userSessionList = new ArrayList();
			}
			userSessionList.add(userSessionID);
			session.setAttribute(USER_SESSION_ID, userSessionList);
		}
		return userInfo;
	}

	/**
	 * setLogoutPFToken method uses the Java Integration Kit API to create an
	 * instance of Sp Agent and construct the logout PFTOKEN
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 * @param userSessionID
	 * 				current session Id
	 * @param redirectURL
	 * 				url to add PFTOKEN
	 * @return String
	 * 				URL with PFTOKEN logout parameter
	 */
	private String setLogoutPFToken(HttpServletRequest request,
			HttpServletResponse response, String url, String userSessionID,
			boolean logoutSuccessful) throws IOException, ServletException {
		String returnURL = url;

		Properties configProperties= getProperties(configFilePath);

		// Get password for encryption
		String password = configProperties.getProperty("password");

		// Get PFTOKEN Holder name
		String holderName = configProperties.getProperty("holderName");

		// Create PFTOKEN Sp Agent
		PFTokenAgent spAgent = new PFTokenAgent(password,holderName);

 		// Set userSessionID in Sp Agent
 		spAgent.setSessionID(userSessionID);
 		try {
 			// Create PFTOKEN 
 			returnURL = spAgent.constructLogoutPFToken(request, response, returnURL, logoutSuccessful);
		}
		catch(PFTokenException e) {
			throw new ServletException(e);
		}
		return returnURL;
	}


	/**
	 * setPFToken method uses the Java Integration Kit API to create an
	 * instance of Sp Agent. The user attributes are added to this agent and
	 * then the PFTOKEN is created as a cookie or query parameter
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 * @param url
	 * 				url to append PFTOKEN
  	 * @param userInfo
	 * 				user attributes
	 * @return String
	 * 				URL with PFTOKEN logout parameter
	 */
	private String setPFToken(HttpServletRequest request,
			HttpServletResponse response, String url, Map userInfo)
			throws IOException, ServletException {
		String returnURL = url;

		Properties configProperties= getProperties(configFilePath);

		// Get password for encryption
		String password = configProperties.getProperty("password");

		// Get PFTOKEN Holder name
		String holderName = configProperties.getProperty("holderName");

		// Create PFTOKEN Sp Agent
		PFTokenAgent spAgent = new PFTokenAgent(password,holderName);

		// Add user attributes to the agent
		spAgent.addAttributes(userInfo);
		try {
			// Create PFTOKEN
			returnURL = spAgent.constructPFToken(request, response, url);
		}
		catch(PFTokenException e) {
			throw new ServletException(e);
		}
		return returnURL;
	}


%>